# Overview

Zimfarm client provides a way to programmatically interact with Zimfarm services.

## Requirements

- Python 3.7.0 or up
- A Internet connection
- Username and password

## How to run 

### Option 1: using source code

1. clone this repository and go into root of the repository
2. make a virtual environment (optional)
3. install dependencies: `pip install -r requirements.txt`
4. set PYTHONPATH environment variable `export PYTHONPATH=$PWD`
5. start writing code and run them, e.g. `python example/list_wokers.py`

### Option 2: install from pip 
Coming soon...

##
